@@ -1,27 +1,16 @@
 # -----------------------------------------------------------------------------
 # TL - Tripletailメインクラス
 # -----------------------------------------------------------------------------
-# $Id: Tripletail.pm,v 1.197 2007/07/19 07:26:29 hio Exp $
 package Tripletail;
 use strict;
 use warnings;
-BEGIN{ our $_CHKNONLAZY=$ENV{PERL_DL_NONLAZY} }
-BEGIN{ our $_CHKDYNALDR=$INC{'DynaLoader.pm'} }
 use UNIVERSAL qw(isa);
-use File::Spec;
-use Data::Dumper;
-use Cwd ();
 
-our $VERSION = '0.29_02';
+our $VERSION = '0.12';
 
 our $TL = Tripletail->__new;
 our @specialization = ();
 our $LOG_SERIAL = 0;
-our $LASTERROR;
-our %_FILE_CACHE;
-my $_FILE_CACHE_MAXSIZE = 10_1024*1024;
-my $_FILE_CACHE_CURSIZE = 150; # variables for caching.
-our $CWD;
 
 require Unicode::Japanese;
 
@@ -30,17 +19,6 @@ if($ENV{TL_COVER_TEST_MODE}) {
 	Devel::Cover->import(qw(-silent on -summary off -db ./cover_db -coverage statement branch condition path subroutine time +ignore ^/));
 }
 
-*errorTrap = \&_errorTrap_is_deprecated;
-sub _errorTrap_is_deprecated {
-	die "\$TL->errorTrap(..) is deprecated, use \$TL->trapEror(..)"
-	#&trapError;
-}
-
-if( $ENV{MOD_PERL} )
-{
-	&PreloadModperl;
-}
-
 1;
 
 # -----------------------------------------------------------------------------
@@ -60,13 +38,7 @@ sub import {
 				or die "use Tripletail, ARG[1]: not defined. Usage: \"use Tripletail qw(config.ini);\"\n";
 			$inifile = '/dev/null';
 		}
-		if( $inifile ne '/dev/null' && $inifile ne 'nul' )
-		{
-			$TL->{INI} = $TL->newIni($inifile);
-		}else
-		{
-			$TL->{INI} = $TL->newIni();
-		}
+		$TL->{INI} = $TL->newIni($inifile);
 		$TL->{INI}->const;
 		
 		if(defined($_[0])) {
@@ -75,16 +47,35 @@ sub import {
 
 		my $trap = $TL->{INI}->get(TL => 'trap', 'die');
 		if($trap ne 'none' && $trap ne 'die' && $trap ne 'diewithprint') {
-			die __PACKAGE__."#import, invalid trap option [$trap].\n";
+			die __PACKAGE__."#startCgi, invalid trap option [$trap].\n";
 		}
 
 
 		$TL->{trap} = $trap;
 
-		if($trap =~ /^(die|diewithprint)$/ )
-		{
-			my $trap = $1;
-			$SIG{__DIE__} = \&__die_handler_for_startup;
+		if($trap eq 'die') {
+			$SIG{__DIE__} = sub {
+				# スタックトレースを付け加えて再度dieする。
+				# それ以外の事はしない。
+				my $msg = shift;
+
+				die isa($msg, 'Tripletail::Error') ? $msg : $TL->newError(error => $msg);
+			};
+		} elsif($trap eq 'diewithprint') {
+			$SIG{__DIE__} = sub {
+				# エラーをヘッダと共に表示して再度dieする。
+				my $msg = shift;
+
+				if (isa($msg, 'Tripletail::Error')) {
+					die $msg;
+				}
+				
+				my $err = $TL->newError(error => $msg);
+				
+				print "Content-Type: text/plain\n\n$err";
+				
+				die $err;
+			};
 		}
 		*{"$callpkg1\::CGI"} = _gensym(); # dummy to avoid strict.
 	} else {
@@ -94,45 +85,6 @@ sub import {
 	}
 }
 
-sub PreloadModperl
-{
-	require Apache2::RequestRec;
-	require Apache2::RequestIO;
-	require Apache2::RequestUtil;
-	require Apache2::Const;
-	Apache2::Const->import(-compile => qw(OK REDIRECT));
-	require APR::Table;
-}
-
-sub __die_handler_for_startup
-{
-	my $msg = shift;
-	my $trap = shift || $TL->{trap};
-
-	if( isa($msg, 'Tripletail::Error') )
-	{
-		die $msg;
-	}
-	my $prev = $LASTERROR;
-	if( $prev && !ref($msg) && $msg =~ s/^\Q$prev\E(?=Compilation failed in require at )// )
-	{
-		$prev->{message} .= $msg;
-		die $prev;
-	}
-
-	my $err = $TL->newError(error => $msg);
-	$LASTERROR = $err;
-
-	if( $trap eq 'diewithprint' && $err->{appear} ne 'usertrap' )
-	{
-		# die-with-print時かつevalの外であればは,
-		# エラーをヘッダと共に表示する.
-		print "Content-Type: text/plain\n\n$err";
-	}
-
-	die $err;
-}
-
 # -----------------------------------------------------------------------------
 # Pod::Coverage内からロードされているかの判定.
 #  (Test::Pod::Cover用)
@@ -185,8 +137,6 @@ sub __new {
 
 	$this->{encode_is_available} = undef; # undef: 不明  0: Encode利用不可  1: Encode利用可
 
-    $this->{fcgi_request} = undef; # FCGI または undef
-
 	$this;
 }
 
@@ -208,42 +158,6 @@ sub INI {
 	$this->{INI};
 }
 
-sub fork {
-    my $this = shift;
-
-    if ($this->{fcgi_request}) {
-        $this->{fcgi_request}->Detach;
-    }
-
-    my $pid = CORE::fork();
-    
-    if (not defined $pid) {
-        die "fork failed: $!";
-    }
-    elsif ($pid == 0) {
-        # child
-        
-        if ($this->{fcgi_request}) {
-            # 何故か FCGI::DESTROY を殺して置かないと、子プロセスの方が早く死んだ
-            # 時に Internal Server Error になってしまう。
-            # http://wiki.dreamhost.com/Perl_FastCGI
-            *FCGI::DESTROY = sub {};
-        }
-        
-        require Tripletail::DB;
-
-        Tripletail::DB::_reconnectSilentlyAll();
-    }
-    else {
-        # parent
-        if ($this->{fcgi_request}) {
-            $this->{fcgi_request}->Attach;
-        }
-    }
-
-    return $pid;
-}
-
 sub escapeTag {
 	my $this = shift;
 	my $str = shift;
@@ -252,7 +166,6 @@ sub escapeTag {
 		die "TL#escapeTag, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/\&/\&amp;/g;
 	$str =~ s/</\&lt;/g;
 	$str =~ s/>/\&gt;/g;
@@ -270,7 +183,6 @@ sub unescapeTag {
 		die "TL#unescapeTag, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/\&lt;/</g;
 	$str =~ s/\&gt;/>/g;
 	$str =~ s/\&quot;/\"/g;
@@ -295,7 +207,6 @@ sub escapeJs {
 		die "TL#escapeJs, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/(['"\\])/\\$1/g;
 	$str =~ s/\r/\\r/g;
 	$str =~ s/\n/\\n/g;
@@ -311,7 +222,6 @@ sub unescapeJs {
 		die "TL#unescapeJs, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/\\(['"\\])/$1/g;
 
 	$str;
@@ -325,7 +235,6 @@ sub encodeURL {
 		die "TL#encodeURL, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/([^a-zA-Z0-9\-\_\.\!\~\*\'\(\)])/
 	'%' . sprintf('%02x', unpack("C", $1))/eg;
 
@@ -340,7 +249,6 @@ sub decodeURL {
 		die "TL#decodeURL, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/\%([a-zA-Z0-9]{2})/pack("C", hex($1))/eg;
 
 	$str;
@@ -354,7 +262,6 @@ sub escapeSqlLike {
 		die "TL#escapeSqlLike, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/\\/\\\\/g;
 	$str =~ s/\%/\\\%/g;
 	$str =~ s/\_/\\\_/g;
@@ -370,7 +277,6 @@ sub unescapeSqlLike {
 		die "TL#unescapeSqlLike, ARG[1]: got undef.\n";
 	}
 
-	$str = "$str"; # stringify.
 	$str =~ s/\\\%/\%/g;
 	$str =~ s/\\\_/\_/g;
 	$str =~ s/\\\\/\\/g;
@@ -378,31 +284,25 @@ sub unescapeSqlLike {
 	$str;
 }
 
-sub __die_handler_for_localeval
-{
-	# スタックトレースを付け加えて再度dieする。
-	# それ以外の事はしない。
-	my $msg = shift;
-
-	die isa($msg, 'Tripletail::Error') ? $msg : $TL->newError(error => $msg);
-}
-
 sub startCgi {
 	my $this = shift;
 	my $param = { @_ };
 	
-	$this->_clearCwd();
 	$this->{outputbuffering} = $this->INI->get(TL => 'outputbuffering', 0);
 
-	my $main_err;
 	eval {
 		# trap = diewithprint の場合はエラーハンドラを付け替える
 		# そうしないと Content-Type: text/plain が出力されてしまう。
 		if($this->{trap} eq 'diewithprint') {
-			$SIG{__DIE__} = \&__die_handler_for_localeval;
+			$SIG{__DIE__} = sub {
+				# スタックトレースを付け加えて再度dieする。
+				# それ以外の事はしない。
+				my $msg = shift;
+
+				die isa($msg, 'Tripletail::Error') ? $msg : $TL->newError(error => $msg);
+			};
 		}
 
-		# Tripletail::Debugをロード。debug機能が有効になっていれば、
 		# ここで各種フック類がインストールされる。
 		$this->getDebug;
 
@@ -416,6 +316,12 @@ sub startCgi {
 			}
 		}
 
+		if(defined(my $groups = $param->{-Session})) {
+			require Tripletail::Session;
+
+			Tripletail::Session->_init($groups);
+		}
+
 		if(!defined($param->{'-main'})) {
 			die __PACKAGE__."#startCgi, -main handler was undef.\n";
 		}
@@ -427,11 +333,6 @@ sub startCgi {
 		if(!$this->getInputFilter) {
 			$this->setInputFilter('Tripletail::InputFilter::HTML');
 		}
-		if( $ENV{MOD_PERL} )
-		{
-			my $r = Apache2::RequestUtil->request;
-			$TL->{mod_perl} = { request => $r };
-		}
 
 		if($this->_getRunMode eq 'FCGI') {
 			# FCGIモードならメモリ監視フックとファイル監視フックをインストール
@@ -439,6 +340,7 @@ sub startCgi {
 			$this->getFileSentinel->__install;
 		}
 
+		$this->__executeHook('init');
 
 		if($this->_getRunMode eq 'FCGI') {
 			# FCGIモード
@@ -449,7 +351,6 @@ sub startCgi {
 
 			do {
 				local $SIG{__DIE__} = 'DEFAULT';
-				#no warnings;
 				eval 'use FCGI';
 			};
 			if($@) {
@@ -459,46 +360,26 @@ sub startCgi {
 			my $exit_requested;
 			my $handling_request;
 			local $SIG{USR1} = sub {
-				$this->log("SIGUSR1 received");
 				$exit_requested = 1;
+				die "SIGUSR1 received\n";
 			};
 			local $SIG{TERM} = sub {
-				# NB: FCGIモードでは、fastcgiマネージャから
-				#     SIGTERMが送られてくる為、
-				#     状況に応じて挙動を変更する(以下を参照)
-				# http://d.tir.jp/pw?mod_fastcgi の一番下
-				# https://192.168.0.17/mantis/view.php?id=1037
-				$this->log("SIGTERM received");
 				$exit_requested = 1;
+				die "SIGTERM received\n";
 			};
 			local $SIG{PIPE} = 'IGNORE';
 
-			{
-				#no warnings;
-				$this->{fcgi_request} = FCGI::Request(
-					\*STDIN, \*STDOUT, \*STDERR, \%ENV,
-					0, FCGI::FAIL_ACCEPT_ON_INTR());
-			}
+			my $request = FCGI::Request(
+				\*STDIN, \*STDOUT, \*STDERR, \%ENV,
+				0, FCGI::FAIL_ACCEPT_ON_INTR());
 
 			while(1) {
 				my $accepted = eval {
-					#no warnings;
-					local $SIG{__DIE__} = 'DEFAULT';
-					local $SIG{USR1} = sub {
-						$exit_requested = 1;
-						die("SIGUSR1 received\n");
-					};
-					local $SIG{TERM} = sub {
-						$exit_requested = 1;
-						die("SIGTERM received\n");
-					};
-					$this->{fcgi_request}->Accept() >= 0;
+					$request->Accept() >= 0;
 				};
 				if($@) {
 					if($exit_requested) {
 						$this->log(FCGI => "FCGI_request->Accept() interrupted : $@");
-						#no warnings;
-						$this->{fcgi_request}->Finish();
 						last;
 					}else {
 						$this->log(FCGI => "FCGI_request->Accept() failed : $@");
@@ -510,53 +391,24 @@ sub startCgi {
 					last;
 				}
 
-				if( $requestcount==0 )
-				{
-					# 最初のリクエスト受信時でプロセスの初期化.
-					if(defined(my $groups = $param->{-Session})) {
-						require Tripletail::Session;
-
-						Tripletail::Session->_init($groups);
-					}
-					$this->__executeHook('init');
-				}
-				
 				$this->__executeCgi($param->{-main});
-				$main_err = $@;
 
-				{
-					#no warnings;
-					$this->{fcgi_request}->Flush;
-				}
+				$request->Flush;
 
 				$requestcount++;
 
 				if($exit_requested || ($maxrequestcount && ($requestcount >= $maxrequestcount))) {
 					last;
 				}
-				$this->{fcgi_restart} and last;
 			}
-			{
-				#no warnings;
-				$this->{fcgi_request}->Finish;
-			}
-            $this->{fcgi_request} = undef;
+			$request->Finish;
 
-			$this->log(FCGI => "FCGI Loop terminated ($requestcount reqs processed).");
+			$this->log(FCGI => 'FCGI Loop terminated.');
 		} else {
 			# CGIモード
 			$this->log(TL => 'CGI mode');
-			
-			# プロセスの初期化.
-			if(defined(my $groups = $param->{-Session})) {
-				require Tripletail::Session;
-
-				Tripletail::Session->_init($groups);
-			}
-			$this->__executeHook('init');
 
 			$this->__executeCgi($param->{-main});
-			$main_err = $@;
 		}
 
 		$this->__executeHook('term');
@@ -581,35 +433,26 @@ sub startCgi {
 			$this->__dispError($err);
 		}
 	}
-	!$@ && $main_err and $@ = $main_err;
 
-	if( $ENV{MOD_PERL} )
-	{
-		Apache2::Const->OK;
-	}else
-	{
-		$this;
-	}
+	$this;
 }
 
-sub _fcgi_restart
-{
-	my $this = shift;
-	@_ and $this->{fcgi_restart} = shift;
-	$this->{fcgi_restart};
-} 
-
-sub trapError {
+sub errorTrap {
 	my $this = shift;
 	my $param = { @_ };
 
-	my $main_err;
 	eval {
 		# trap = diewithprint の場合はエラーハンドラを付け替える
-		# そうしないと Content-Type: text/plain が出力されてしまう。
-		local($SIG{__DIE__}) = 'DEFAULT';
+		# そうしないと Content-Type: text/plain が出力されてしまう
+		local($SIG{__DIE__});
 		if ($this->{trap} eq 'diewithprint'){
-			$SIG{__DIE__} = \&__die_handler_for_localeval;
+			$SIG{__DIE__} = sub {
+				# スタックトレースを付け加えて再度dieする。
+				# それ以外の事はしない。
+				my $msg = shift;
+
+				die isa($msg, 'Tripletail::Error') ? $msg : $TL->newError(error => $msg);
+			};
 		}
 		# Tripletail::Debugをロード。debug機能が有効になっていれば、
 		# ここで各種フック類がインストールされる。
@@ -626,7 +469,7 @@ sub trapError {
 		}
 
 		if(!defined($param->{'-main'})) {
-			die __PACKAGE__."#trapError, -main handler was undef.\n";
+			die __PACKAGE__."#errorTrap, -main handler was undef.\n";
 		}
 
 		$this->__executeHook('init');
@@ -636,7 +479,6 @@ sub trapError {
 		eval {
 			$param->{'-main'}();
 		};
-		$main_err = $@;
 		if(my $err = $@) {
 			if($this->{trap} eq 'none') {
 				die $err;
@@ -661,10 +503,9 @@ sub trapError {
 		}
 
 		# このevalでキャッチされたという事は、-mainの外で例外が起きた。
-		$this->log(trapError => "Died outside the `-main': $err");
-		print STDERR __PACKAGE__."#trapError, Died outside the `-main': $err\n";
+		$this->log(errorTrap => "Died outside the `-main': $err");
+		print STDERR "Died outside the `-main': $err\n";
 	}
-	!$@ && $main_err and $@ = $main_err;
 
 	$this;
 }
@@ -709,51 +550,22 @@ sub dispatch {
 
 sub log {
 	my $this = shift;
-    my $group;
-    my $message;
-
-    my $stringify = sub {
-        my $val = shift;
-        
-        if (ref $val) {
-            Data::Dumper->new([$val])
-              ->Indent(1)->Purity(0)->Useqq(1)->Terse(1)->Deepcopy(1)
-                ->Quotekeys(0)->Sortkeys(1)->Deparse(1)->Dump;
-        }
-        else {
-            $val; # 元々スカラーだった
-        }
-    };
-    
-    if (@_ == 1) {
-        # "呼出し元ファイル名(行数):関数名"
-        my ($filename, $line) = (caller 0)[1, 2];
-        my $sub = (caller 1)[3];
-
-        $group   = sprintf '%s(%d) >> %s', $filename, $line, $sub;
-        $message = $stringify->(shift);
-    }
-    elsif (@_ == 2) {
-        $group   = shift;
-        $message = $stringify->(shift);
-    }
-    else {
-        die "TL#log, invalid call of \$TL->log().\n";
-    }
+	my $group = shift;
+	my $log = shift;
 
 	if(!defined($group)) {
 		die "TL#log, ARG[1]: got undef.\n";
 	}
-	if(!defined($message)) {
+	if(!defined($log)) {
 		die "TL#log, ARG[2]: got undef.\n";
 	}
 
 	$this->getDebug->_tlLog(
 		group => $group,
-		log   => $message,
+		log   => $log,
 	);
 
-	$this->_log($group, $message);
+	$this->_log($group, $log);
 }
 
 sub _log {
@@ -792,7 +604,7 @@ sub _log {
 		. sprintf('%04d%02d/%02d-%02d.log', @localtime[5,4,3,2]);
 
 	if(!exists($this->{cacheLogPath}) || !defined($dirstat[1]) || $path ne $this->{cacheLogPath}) {
-		# month is changed.
+
 		delete $this->{cacheLogFh};
 		my $umask = umask(0);
 		local($@);
@@ -820,7 +632,6 @@ sub _log {
 	my @stat = stat($path);
 	if(!defined($this->{cacheLogFh}) || !defined($stat[1]) || ($this->{cacheLogInode} != $stat[1])) {
 
-		# hour is changed.
 		my $fh = $this->_gensym;
 		if(!open($fh, ">>$path")) {
 			print "Content-Type: text/plain\n\n";
@@ -837,15 +648,6 @@ sub _log {
 		my @newstat = stat($path);
 		$this->{cacheLogFh} = $fh;
 		$this->{cacheLogInode} = $newstat[1];
-		local($@);
-		eval
-		{
-			my $rel_to_logfile = sprintf('%04d%02d/%02d-%02d.log', @localtime[5,4,3,2]);
-			local($SIG{__DIE__});
-			my $cur_linkfile = File::Spec->catfile($this->{logdir}, "current");
-			unlink($cur_linkfile);
-			symlink($rel_to_logfile, $cur_linkfile);
-		};
 	}
 
 	my $fh = $this->{cacheLogFh};
@@ -1084,12 +886,6 @@ sub _sendErrorIfNeeded {
 	}
 }
 
-sub _hostname
-{
-	my $host = `hostname -f 2>&1` || `hostname 2>&1`;
-	$host && $host=~/^\s*([\w.-]+)\s*$/ ? $1 : '';
-}
-
 sub sendError {
 	my $this = shift;
 	my $opts = { @_ };
@@ -1123,7 +919,11 @@ sub sendError {
 	push @lines, '';
 	push @lines, '----';
 
-	my $host = _hostname();
+	my $host = '';
+	eval { $host = `hostname -f` };
+	if(!$host) {
+		eval { $host = `hostname` };
+	}
 	if($host) {
 		chomp $host;
 		unshift @lines, "HOST: $host";
@@ -1269,9 +1069,7 @@ sub parsePeriod {
 		} elsif(s/^days?//) {
 			commit(60 * 60 * 24);
 		} elsif(s/^mon(?:ths?)?//) {
-			commit(60 * 60 * 24 * 30.436875);
-		} elsif(s/^years?//) {
-			commit(60 * 60 * 24 * 365.2425);
+			commit(60 * 60 * 24 * 30);
 		} elsif(s/^(\d+)//) {
 			if(defined($lastnum)) {
 				die __PACKAGE__."#parsePeriod, invalid time string [$str]:".
@@ -1288,7 +1086,7 @@ sub parsePeriod {
 		commit(1);
 	}
 
-	int($result);
+	$result;
 }
 
 sub parseQuantity {
@@ -1403,7 +1201,7 @@ sub getDebug {
 	my $this = shift;
 
 	require Tripletail::Debug;
-	
+
 	Tripletail::Debug->_getInstance(@_);
 }
 
@@ -1501,14 +1299,8 @@ sub newTagCheck {
 
 sub newTemplate {
 	my $this = shift;
-	
-	my $err;
-	{
-		local($@);
-		eval{ require Tripletail::Template; };
-		$err = $@;
-	}
-	$err and die $err;
+
+	require Tripletail::Template;
 
 	Tripletail::Template->_new(@_);
 }
@@ -1542,16 +1334,12 @@ sub newError {
 
 	# Tripletail::Error のロード失敗は特別に扱わなければならない。
 	# die ハンドラがこれを利用する為である。
-	if( !Tripletail::Error->can("_new") )
-	{
-		local($@);
-		eval {
-			require Tripletail::Error;
-		};
-		if ($@) {
-			print STDERR $@;
-			exit 1;
-		}
+	eval {
+		require Tripletail::Error;
+	};
+	if ($@) {
+		print STDERR $@;
+		exit 1;
 	}
 
 	Tripletail::Error->_new(@_);
@@ -1589,79 +1377,6 @@ sub charconv {
 	Tripletail::CharConv->_getInstance()->_charconv(@_);
 }
 
-# -----------------------------------------------------------------------------
-# ファイル関連.
-# -----------------------------------------------------------------------------
-
-sub _filecacheMax
-{
-	my $this = shift;
-	@_ and $_FILE_CACHE_MAXSIZE = shift;
-	$_FILE_CACHE_MAXSIZE;
-}
-
-sub _filecacheMemorySize
-{
-	$_FILE_CACHE_CURSIZE;
-}
-
-sub _fetchFileCache
-{
-	my $this = shift;
-	my $fpath = shift;
-	
-	my $now = time;
-	
-	my ($inode, $size, $mtime);
-	
-	if( my $cache = $_FILE_CACHE{$fpath} )
-	{
-		if( $cache->{fetch_at}==$now )
-		{
-			return $cache;
-		}
-		
-		my @st = stat($fpath);
-		@st or die __PACKAGE__."#_fetchFileCache, Failed to stat file [$fpath]: $!\n";
-		($inode, $size, $mtime) = @st[1, 7, 9];
-		if( $inode==$cache->{inode} && $size==$cache->{size} && $mtime==$cache->{mtime} )
-		{
-			$cache->{fetch_at} = $now;
-			return $cache;
-		}
-		
-		# unload.
-		$_FILE_CACHE_CURSIZE -= $cache->{cache_size};
-		delete $_FILE_CACHE{$fpath};
-	}else
-	{
-		my @st = stat($fpath);
-		@st or die __PACKAGE__."#_fetchFileCache, Failed to stat file [$fpath]: $!\n";
-		($inode, $size, $mtime) = @st[1, 7, 9];
-	}
-	
-	my $cache = {
-		inode => $inode,
-		size  => $size,
-		mtime => $mtime,
-		path  => $fpath,
-		data  => undef,
-		text  => undef,
-		
-		fetch_at   => $now,
-		cache_size => 312 + 24*5 + (25+length($fpath)) + 12*2,
-	};
-	if( $mtime < $now )
-	{
-		$_FILE_CACHE{$fpath} = $cache;
-		$_FILE_CACHE_CURSIZE += $cache->{cache_size};
-	}else
-	{
-		$cache->{cache_size} = undef;
-	}
-	$cache;
-}
-
 sub readFile {
 	my $this = shift;
 	my $fpath = shift;
@@ -1672,21 +1387,11 @@ sub readFile {
 		die __PACKAGE__."#readFile, ARG[1] was a Ref. [$fpath]\n";
 	}
 
-	my $cache = $this->_fetchFileCache($fpath);
-	if( !defined($cache->{data}) )
-	{
-		open my $fh, '<', $fpath
-			or die __PACKAGE__."#readFile, Failed to read file [$fpath]: $!\n";
+	open my $fh, '<', $fpath
+	  or die __PACKAGE__."#readFile, Failed to read file [$fpath]: $!\n";
 
-		local $/ = undef;
-		$cache->{data} = <$fh>;
-		if( $cache->{cache_size} )
-		{
-			$cache->{cache_size} += 25 + length($cache->{data});
-			$_FILE_CACHE_CURSIZE  += 25 + length($cache->{data});
-		}
-	}
-	$cache->{data};
+	local $/ = undef;
+	<$fh>;
 }
 
 sub readTextFile {
@@ -1695,33 +1400,12 @@ sub readTextFile {
 	my $coding = shift;
 	my $prefer_encode = shift;
 
-	my $cache = $this->_fetchFileCache($fpath);
-	if( !defined($cache->{text}) )
-	{
-		$cache->{text} = $this->charconv(
-			$this->readFile($fpath),
-			$coding,
-			'utf8',
-			$prefer_encode,
-		);
-		if( $cache->{cache_size} )
-		{
-			$cache->{cache_size} += 25 + length($cache->{text});
-			$_FILE_CACHE_CURSIZE += 25 + length($cache->{text});
-		}
-		
-		# rawデータは使わないと思うので削除.
-		if( defined($cache->{data}) )
-		{
-			if( $cache->{cache_size} )
-			{
-				$cache->{cache_size} -= 25 + length($cache->{data});
-				$_FILE_CACHE_CURSIZE -= 25 + length($cache->{data});
-			}
-			delete $cache->{data};
-		}
-	}
-	$cache->{text};
+	$this->charconv(
+		$this->readFile($fpath),
+		$coding,
+		'utf8',
+		$prefer_encode,
+	);
 }
 
 sub writeFile {
@@ -1771,9 +1455,6 @@ sub writeTextFile {
 	);
 }
 
-# -----------------------------------------------------------------------------
-# --
-# -----------------------------------------------------------------------------
 sub watch {
 	my $this = shift;
 
@@ -1783,59 +1464,20 @@ sub watch {
 }
 
 sub dump {
-    # dump($group, $obj)
-    # dump($group, $obj, $level)
-    # dump($obj)
-    # dump($obj, $level)
 	my $this = shift;
-    my $group;
-    my $val;
-    my $level;
+	my $group = shift;
+	my $var = shift;
+	my $level = shift || 0;
 
-    my $auto_group = sub {
-        # "呼出し元ファイル名(行数):関数名"
-        my ($filename, $line) = (caller 1)[1, 2];
-        my $sub = (caller 2)[3];
+	local($@);
+	eval {
+		use Data::Dumper;
+		my $dump = Data::Dumper->new([$var])
+			->Maxdepth($level)->Indent(1)->Terse(1)->Dump;
+		$this->log($group => $dump);
+	};
 
-        sprintf '%s(%d) >> %s', $filename, $line, $sub;
-    };
-
-    if (@_ == 0 || @_ > 3) {
-        die __PACKAGE__."#dump, invalid call of \$TL->dump().\n";
-    }
-    elsif (@_ == 1) {
-        $group = $auto_group->();
-        $val   = shift;
-        $level = 0;
-    }
-    elsif (@_ == 2) {
-        if (ref $_[0]) {
-            # dump($obj, $level)
-            $group = $auto_group->();
-            $val   = shift;
-            $level = shift;
-        }
-        else {
-            # dump($group, $obj)
-            $group = shift;
-            $val   = shift;
-            $level = 0;
-        }
-    }
-    elsif (@_ == 3) {
-        $group = shift;
-        $val   = shift;
-        $level = shift;
-    }
-    else {
-        die "Internal error";
-    }
-
-    my $dump = Data::Dumper->new([$val])
-      ->Indent(1)->Purity(0)->Useqq(1)->Terse(1)->Deepcopy(1)
-        ->Quotekeys(0)->Sortkeys(1)->Deparse(1)->Maxdepth($level)->Dump;
-
-    $this->log($group => $dump);
+	$this;
 }
 
 sub printCacheUnlessModified {
@@ -2096,15 +1738,6 @@ sub __flushContentFilter {
 	print $str;
 }
 
-sub _cwd
-{
-	$CWD ||= Cwd::cwd;
-}
-sub _clearCwd
-{
-	$CWD = undef;
-}
-
 __END__
 
 =encoding utf-8
@@ -2332,15 +1965,12 @@ FastCGIとしてプログラムを動作させるモード。httpdからfcgiス
 C<use Tripletail> したスクリプトファイルや、その L<Ini|Tripletail::Ini> ファイルの最終更新時刻
 も監視し、更新されていたら自動的に終了する。
 
-このモードでは fork が正しく動作しない事に注意。代わりに
-L<< $TL->fork|/"fork" >> メソッドを使用する。
-
 =item 一般スクリプトモード
 
 CGIでない一般のスクリプトとしてプログラムを動作させるモード。
 CGIモード特有の機能は利用出来ない。
 
-このモードでは L<< $TL->trapError|/"trapError" >> メソッドで L</"Main関数"> を呼ぶ。
+このモードでは L<< $TL->errorTrap|/"errorTrap" >> メソッドで L</"Main関数"> を呼ぶ。
 
 =back
 
@@ -2373,7 +2003,7 @@ L<< $TL->setHook|/"setHook" >> メソッドを用いてフックを掛ける事
 
 =item init
 
-L</"startCgi"> もしくは L</"trapError"> が呼ばれ、最初に L</"Main関数"> が
+L</"startCgi"> もしくは L</"errorTrap"> が呼ばれ、最初に L</"Main関数"> が
 呼ばれる前。
 
 =item preRequest
@@ -2387,16 +2017,81 @@ L</"Main関数"> が呼ばれた直後。
 =item term
 
 最後に L</"Main関数"> が呼ばれた後。termフック呼出し後に L</"startCgi">
-もしくは L</"trapError"> が終了する。
+もしくは L</"errorTrap"> が終了する。
 
 =back
 
 
 =head2 METHODS
 
-=head3 よく使うもの
+=over 4
 
-=head4 C<< startCgi >>
+=item C<< INI >>
+
+  $TL->INI
+
+C<< use Tripletail qw(filename.ini); >> で読み込まれた L<Tripletail::Ini> を返す。
+
+=item C<< CGI >>
+
+  $TL->CGI
+  $CGI
+
+リクエストを受け取った L<Tripletail::Form> オブジェクトを返す。
+また、このオブジェクトは startCgi メソッドの呼び出し元パッケージに export される。
+
+このメソッドがundefでない値を返すのは、 L</"preRequest"> フックが呼ばれる
+直前から L</"postRequest"> フックが呼ばれた直後までである。
+
+=item C<< escapeTag >>
+
+  $result = $TL->escapeTag($value)
+
+&E<lt>E<gt>"' の文字をエスケープ処理した文字列を返す。
+
+=item C<< unescapeTag >>
+
+  $result = $TL->unescapeTag($value)
+
+&E<lt>E<gt>"'&#??;&#x??; にエスケープ処理された文字を元に戻した文字列を返す。
+
+=item C<< escapeJs >>
+
+  $result = $TL->escapeJs($value)
+
+'"\ の文字を \ を付けてエスケープし，'\r' '\n' について '\\r' '\\n' に置き換える。
+
+=item C<< unescapeJs >>
+
+  $result = $TL->unescapeJs($value)
+
+escapeJs した文字列を元に戻す。
+
+=item C<< encodeURL >>
+
+  $result = $TL->encodeURL($value)
+
+文字列をURLエンコードした結果を返す。
+
+=item C<< decodeURL >>
+
+  $result = decodeURL($value)
+
+URLエンコードを解除し元に戻した文字列を返す。
+
+=item C<< escapeSqlLike >>
+
+  $result = $TL->escapeSqlLike($value)
+
+% _ \ の文字を \ でエスケープ処理した文字列を返す。
+
+=item C<< unescapeSqlLike >>
+
+  $result = $TL->unescapeSqlLike($value)
+
+\% \_ \\ にエスケープ処理された文字を元に戻した文字列を返す。
+
+=item C<< startCgi >>
 
   $TL->startCgi(
     -main        => \&Main,    # メイン関数
@@ -2422,20 +2117,19 @@ C<Session> は、次のように配列へのリファレンスを渡す事で、
     -Session => ['Session1', 'Session2'],
   );
 
-通常スクリプトでは L</trapError> を参照.
+=item C<< errorTrap >>
 
-=head4 C<< CGI >>
+  $TL->errorTrap(
+    -main => \&Main, # メイン関数
+    -DB   => 'DB',   # DBを使う場合，iniのグループ名を指定
+  );
 
-  $TL->CGI
-  $CGI
+環境を整え、 L</"Main関数"> を実行する。
+L</"Main関数"> がdieした場合は、エラー内容が標準エラーへ出力される。
 
-リクエストを受け取った L<Tripletail::Form> オブジェクトを返す。
-また、このオブジェクトは startCgi メソッドの呼び出し元パッケージに export される。
+L</"startCgi"> と同様に、C<DB> には配列へのリファレンスを渡す事も出来る。
 
-このメソッドがundefでない値を返すのは、 L</"preRequest"> フックが呼ばれる
-直前から L</"postRequest"> フックが呼ばれた直後までである。
-
-=head4 C<< dispatch >>
+=item C<< dispatch >>
 
   $result = $TL->dispatch($value, default => $default, onerror => \&Error)
 
@@ -2462,7 +2156,102 @@ onerrorが設定されていた場合、関数が存在しなければ onerror
       ...
   }
 
-=head4 C<< print >>
+=item C<< log >>
+
+  $TL->log($group => $log)
+
+ログを記録する。グループとログデータの２つを受け取る。
+
+ログにはヘッダが付けられ、ヘッダは「時刻(epoch値の16進数8桁表現) プロセスIDの16進数4桁表現 FastCGIのリクエスト回数の16進数4桁表現 [グループ]」の形で付けられる。
+
+=item C<< getLogHeader >>
+
+  my $logid = $TL->getLogHeader
+
+ログを記録するときのヘッダと同じ形式の文字列を生成する。
+「時刻(epoch値の16進数8桁表現) プロセスIDの16進数4桁表現 FastCGIのリクエスト回数の16進数4桁表現」の形の文字列が返される。
+
+=item C<< setHook >>
+
+  $TL->setHook($type, $priority, \&func)
+
+指定タイプの指定プライオリティのフックを設定する。
+既に同一タイプで同一プライオリティのフックが設定されていた場合、
+古いフックの設定は解除される。
+
+typeは、L</"init">, L</"term">, L</"preRequest">, L</"postRequest">
+の４種類が存在する。
+
+なお、1万の整数倍のプライオリティは Tripletail 内部で使用される。アプリ
+ケーション側で不用意に用いるとフックを上書きしてしまう可能性があるので
+注意する。
+
+=item C<< removeHook >>
+
+  $TL->removeHook($type, $priority)
+
+指定タイプの指定プライオリティのフックを削除する。
+
+=item C<< setContentFilter >>
+
+  $TL->setContentFilter($classname, %option)
+  $TL->setContentFilter([$classname, $priority], %option)
+  $TL->setContentFilter('Tripletail::Filter::HTML', charset => 'Shift_JIS')
+  $TL->setContentFilter(
+      'Tripletail::Filter::CSV', charset => 'Shift_JIS', filename => 'テストデータ.csv')
+
+L</"出力フィルタ"> を設定する。
+全ての出力の前に実行する必要がある。
+２番目の書式では、プライオリティを指定して独自のコンテンツフィルタを追加できる。
+省略時は優先度は1000となる。同一優先度のフィルタが既にセットされているときは、
+以前のフィルタ設定は解除される。
+
+返される値は、指定された L<Tripletail::Filter> のサブクラスのインスタンスである。
+
+設定したフィルタは、L</"preRequest"> のタイミングで保存され、
+L</"postRequest"> のタイミングで元に戻される。従って、L</"Main関数">内
+で setContentFilter を実行した場合、その変更は次回リクエスト時に持ち越
+されない。
+
+=item C<< getContentFilter >>
+
+  $TL->getContentFilter($priority)
+
+指定されたプライオリティのフィルタを取得する。省略時は1000となる。
+
+=item C<< removeContentFilter >>
+
+  $TL->removeContentFilter($priority)
+
+指定されたプライオリティのフィルタを削除する。省略時は1000となる。
+フィルタが１つもない場合は、致命的エラーとなり出力関数は使用できなくなる。
+
+=item C<< setInputFilter >>
+
+  $TL->setInputFilter($classname, %option)
+  $TL->setInputFilter([$classname, $priority], %option)
+
+L</"入力フィルタ"> を設定する。
+L</"startCgi"> の前に実行する必要がある。
+
+返される値は、指定された L<Tripletail::InputFilter> のサブクラスのインスタンスである。
+
+=item C<< getInputFilter >>
+
+  $TL->getInputFilter($priority)
+
+=item C<< removeInputFilter >>
+
+  $TL->removeInputFilter($priority)
+
+=item C<< sendError >>
+
+  $TL->sendError(-title => "タイトル", -error => "エラー")
+
+L<ini|Tripletail::Ini> で指定されたアドレスにエラーメールを送る。
+設定が無い場合は何もしない。
+
+=item C<< print >>
 
   $TL->print($str)
 
@@ -2472,64 +2261,120 @@ onerrorが設定されていた場合、関数が存在しなければ onerror
 フィルタによってはバッファリングされる場合もあるが、
 基本的にはバッファリングされない。
 
-=head4 C<< location >>
+=item C<< location >>
 
   $TL->location('http://example.org/')
 
 CGIモードの時、指定されたURLへリダイレクトする。
 このメソッドはあらゆる出力の前に呼ばなくてはならない。 
 
-=head3 変換処理
+=item C<< parsePeriod >>
 
-=head4 C<< escapeTag >>
+  $TL->parsePeriod('10hour 30min')
 
-  $result = $TL->escapeTag($value)
+時間指定文字列を秒数に変換する。
+L</"度量衡"> を参照。
 
-&E<lt>E<gt>"' の文字をエスケープ処理した文字列を返す。
+=item C<< parseQuantity >>
 
-=head4 C<< unescapeTag >>
+  $TL->parseQuantity('100mi 50ki')
 
-  $result = $TL->unescapeTag($value)
+量指定文字列を元の数に変換する。
+L</"度量衡"> を参照。
 
-&E<lt>E<gt>"'&#??;&#x??; にエスケープ処理された文字を元に戻した文字列を返す。
+=item C<< getCookie >>
 
-=head4 C<< escapeJs >>
+L<Tripletail::Cookie> オブジェクトを取得。
 
-  $result = $TL->escapeJs($value)
+=item C<< getCsv >>
 
-'"\ の文字を \ を付けてエスケープし，'\r' '\n' について '\\r' '\\n' に置き換える。
+L<Tripletail::CSV> オブジェクトを取得。
 
-=head4 C<< unescapeJs >>
+=item C<< newDateTime >>
 
-  $result = $TL->unescapeJs($value)
+L<Tripletail::DateTime> オブジェクトを作成。
 
-escapeJs した文字列を元に戻す。
+=item C<< getDB >>
 
-=head4 C<< encodeURL >>
+  $DB = $TL->getDB($group)
 
-  $result = $TL->encodeURL($value)
+L<Tripletail::DB> オブジェクトを取得。
 
-文字列をURLエンコードした結果を返す。
+=item C<< newDB >>
 
-=head4 C<< decodeURL >>
+  $DB = $TL->newDB($group)
 
-  $result = decodeURL($value)
+L<Tripletail::DB> オブジェクトを作成。
 
-URLエンコードを解除し元に戻した文字列を返す。
+=item C<< getFileSentinel >>
 
-=head4 C<< escapeSqlLike >>
+L<Tripletail::FileSentinel> オブジェクトを取得。
 
-  $result = $TL->escapeSqlLike($value)
+=item C<< newForm >>
 
-% _ \ の文字を \ でエスケープ処理した文字列を返す。
+L<Tripletail::Form> オブジェクトを作成。
 
-=head4 C<< unescapeSqlLike >>
+=item C<< newHtmlFilter >>
 
-  $result = $TL->unescapeSqlLike($value)
+L<Tripletail::HtmlFilter> オブジェクトを作成。
 
-\% \_ \\ にエスケープ処理された文字を元に戻した文字列を返す。
+=item C<< newHtmlMail >>
 
-=head4 C<< charconv >>
+L<Tripletail::HtmlMail> オブジェクトを作成。
+
+=item C<< newIni >>
+
+L<Tripletail::Ini> オブジェクトを作成。
+
+=item C<< newMail >>
+
+L<Tripletail::Mail> オブジェクトを作成。
+
+=item C<< getMemorySentinel >>
+
+L<Tripletail::MemorySentinel> オブジェクトを取得。
+
+=item C<< newPager >>
+
+L<Tripletail::Pager> オブジェクトを作成。
+
+=item C<< getRawCookie >>
+
+L<Tripletail::RawCookie> オブジェクトを取得。
+
+=item C<< newSendmail >>
+
+L<Tripletail::Sendmail> オブジェクトを作成。
+
+=item C<< newSMIME >>
+
+L<Tripletail::SMIME> オブジェクトを作成。
+
+=item C<< newTagCheck >>
+
+L<Tripletail::TagCheck> オブジェクトを作成。
+
+=item C<< newTemplate >>
+
+L<Tripletail::Template> オブジェクトを作成。
+
+=item C<< getSession >>
+
+L<Tripletail::Session> オブジェクトを取得。
+
+=item C<< newValue >>
+
+L<Tripletail::Value> オブジェクトを作成。
+
+=item C<< newValidator >>
+
+L<Tripletail::Validator> オブジェクトを生成。
+
+=item C<< newMemCached >>
+
+L<Tripletail::MemCached> オブジェクトを生成。
+
+=item C<< charconv >>
 
   $str = $TL->charconv($str, $from, $to, $prefer_encode);
   $str = $TL->charconv($str, [$from1, $from2, ...], $to, $prefer_encode);
@@ -2555,256 +2400,14 @@ C<$to> が省略された場合は C<'UTF-8'> になる。
 確実に指定できる文字コードは、UTF-8，Shift_JIS，EUC-JP，ISO-2022-JP である。
 それ以外の場合は、L<Encode> と L<Unicode::Japanese> のどちらが使用されるかにより使用できるものが異なる。
 
-=head4 C<< parsePeriod >>
-
-  $TL->parsePeriod('10hour 30min')
-
-時間指定文字列を秒数に変換する。小数点が発生した場合は切り捨てる。
-L</"度量衡"> を参照。
-
-=head4 C<< parseQuantity >>
-
-  $TL->parseQuantity('100mi 50ki')
-
-量指定文字列を元の数に変換する。
-L</"度量衡"> を参照。
-
-=head3 インスタンス生成取得
-
-=head4 C<< getDB >>
-
-  $DB = $TL->getDB($group)
-
-L<Tripletail::DB> オブジェクトを取得。
-
-=head4 C<< newDB >>
-
-  $DB = $TL->newDB($group)
-
-L<Tripletail::DB> オブジェクトを作成。
-
-=head4 C<< newForm >>
-
-L<Tripletail::Form> オブジェクトを作成。
-
-=head4 C<< newTemplate >>
-
-L<Tripletail::Template> オブジェクトを作成。
-
-=head4 C<< getSession >>
-
-L<Tripletail::Session> オブジェクトを取得。
-
-=head4 C<< newValidator >>
-
-L<Tripletail::Validator> オブジェクトを生成。
-
-=head4 C<< newValue >>
-
-L<Tripletail::Value> オブジェクトを作成。
-
-=head4 C<< newDateTime >>
-
-L<Tripletail::DateTime> オブジェクトを作成。
-
-=head4 C<< newPager >>
-
-L<Tripletail::Pager> オブジェクトを作成。
-
-=head4 C<< getCsv >>
-
-L<Tripletail::CSV> オブジェクトを取得。
-
-=head4 C<< newTagCheck >>
-
-L<Tripletail::TagCheck> オブジェクトを作成。
-
-=head4 C<< newHtmlFilter >>
-
-L<Tripletail::HtmlFilter> オブジェクトを作成。
-
-=head4 C<< newHtmlMail >>
-
-L<Tripletail::HtmlMail> オブジェクトを作成。
-
-=head4 C<< newMail >>
-
-L<Tripletail::Mail> オブジェクトを作成。
-
-=head4 C<< newIni >>
-
-L<Tripletail::Ini> オブジェクトを作成。
-
-=head4 C<< getCookie >>
-
-L<Tripletail::Cookie> オブジェクトを取得。
-
-=head4 C<< getRawCookie >>
-
-L<Tripletail::RawCookie> オブジェクトを取得。
-
-=head4 C<< newSendmail >>
-
-L<Tripletail::Sendmail> オブジェクトを作成。
-
-=head4 C<< newSMIME >>
-
-L<Tripletail::SMIME> オブジェクトを作成。
-
-=head4 C<< getFileSentinel >>
-
-L<Tripletail::FileSentinel> オブジェクトを取得。
-
-=head4 C<< getMemorySentinel >>
-
-L<Tripletail::MemorySentinel> オブジェクトを取得。
-
-=head4 C<< newMemCached >>
-
-L<Tripletail::MemCached> オブジェクトを生成。
-
-=head3 その他
-
-=head4 C<< INI >>
-
-  $TL->INI
-
-C<< use Tripletail qw(filename.ini); >> で読み込まれた L<Tripletail::Ini> を返す。
-
-=head4 C<< trapError >>
-
-  $TL->trapError(
-    -main => \&Main, # メイン関数
-    -DB   => 'DB',   # DBを使う場合，iniのグループ名を指定
-  );
-
-環境を整え、 L</"Main関数"> を実行する。
-L</"Main関数"> がdieした場合は、エラー内容が標準エラーへ出力される。
-
-L</"startCgi"> と同様に、C<DB> には配列へのリファレンスを渡す事も出来る。
-
-=head4 C<< fork >>
-
-  if (my $pid = $TL->fork) {
-      # parent
-  }
-  else {
-      # child
-  }
-
-FastCGI 環境を考慮しながら fork を実行する。FastCGI 環境でない場合は通
-常通りに fork する。fork に失敗した場合は die する。
-
-通常は perl 組込み関数である fork を使用しても問題無いが、FastCGI 環境
-では正常に動作しない為、Tripletail アプリケーションは常に fork でなく
-C<< $TL->fork >> を使用する事が推奨される。
-
-=head4 C<< log >>
-
-  $TL->log($group => $log)
-
-ログを記録する。グループとログデータの２つを受け取る。
-
-第一引数のグループは省略可能。
-
-ログにはヘッダが付けられ、ヘッダは「時刻(epoch値の16進数8桁表現) プロセスIDの16進数4桁表現 FastCGIのリクエスト回数の16進数4桁表現 [グループ]」の形で付けられる。
-
-=head4 C<< setContentFilter >>
-
-  $TL->setContentFilter($classname, %option)
-  $TL->setContentFilter([$classname, $priority], %option)
-  $TL->setContentFilter('Tripletail::Filter::HTML', charset => 'Shift_JIS')
-  $TL->setContentFilter(
-      'Tripletail::Filter::CSV', charset => 'Shift_JIS', filename => 'テストデータ.csv')
-
-L</"出力フィルタ"> を設定する。
-全ての出力の前に実行する必要がある。
-２番目の書式では、プライオリティを指定して独自のコンテンツフィルタを
-追加できる。省略時は優先度は1000となる。小さい優先度のフィルタが先に、
-大きい優先度のフィルタが後に呼ばれる。同一優先度のフィルタが既に
-セットされているときは、以前のフィルタ設定は解除される。
-
-返される値は、指定された L<Tripletail::Filter> のサブクラスのインスタンスである。
-
-設定したフィルタは、L</"preRequest"> のタイミングで保存され、
-L</"postRequest"> のタイミングで元に戻される。従って、L</"Main関数">内
-で setContentFilter を実行した場合、その変更は次回リクエスト時に持ち越
-されない。
-
-=head4 C<< getContentFilter >>
-
-  $TL->getContentFilter($priority)
-
-指定されたプライオリティのフィルタを取得する。省略時は1000となる。
-
-=head4 C<< removeContentFilter >>
-
-  $TL->removeContentFilter($priority)
-
-指定されたプライオリティのフィルタを削除する。省略時は1000となる。
-フィルタが１つもない場合は、致命的エラーとなり出力関数は使用できなくなる。
-
-=head4 C<< getLogHeader >>
-
-  my $logid = $TL->getLogHeader
-
-ログを記録するときのヘッダと同じ形式の文字列を生成する。
-「時刻(epoch値の16進数8桁表現) プロセスIDの16進数4桁表現 FastCGIのリクエスト回数の16進数4桁表現」の形の文字列が返される。
-
-=head4 C<< setHook >>
-
-  $TL->setHook($type, $priority, \&func)
-
-指定タイプの指定プライオリティのフックを設定する。
-既に同一タイプで同一プライオリティのフックが設定されていた場合、
-古いフックの設定は解除される。
-
-typeは、L</"init">, L</"term">, L</"preRequest">, L</"postRequest">
-の４種類が存在する。
-
-なお、1万の整数倍のプライオリティは Tripletail 内部で使用される。アプリ
-ケーション側で不用意に用いるとフックを上書きしてしまう可能性があるので
-注意する。
-
-=head4 C<< removeHook >>
-
-  $TL->removeHook($type, $priority)
-
-指定タイプの指定プライオリティのフックを削除する。
-
-=head4 C<< setInputFilter >>
-
-  $TL->setInputFilter($classname, %option)
-  $TL->setInputFilter([$classname, $priority], %option)
-
-L</"入力フィルタ"> を設定する。
-L</"startCgi"> の前に実行する必要がある。
-
-返される値は、指定された L<Tripletail::InputFilter> のサブクラスのインスタンスである。
-
-=head4 C<< getInputFilter >>
-
-  $TL->getInputFilter($priority)
-
-=head4 C<< removeInputFilter >>
-
-  $TL->removeInputFilter($priority)
-
-=head4 C<< sendError >>
-
-  $TL->sendError(-title => "タイトル", -error => "エラー")
-
-L<ini|Tripletail::Ini> で指定されたアドレスにエラーメールを送る。
-設定が無い場合は何もしない。
-
-=head4 C<< readFile >>
+=item C<< readFile >>
 
   $data = $TL->readFile($fpath);
 
 ファイルを読み込む。文字コード変換をしない。
 ファイルロック処理は行わないので、使用の際には注意が必要。
 
-=head4 C<< readTextFile >>
+=item C<< readTextFile >>
 
   $data = $TL->readTextFile($fpath, $coding, $prefer_encode);
 
@@ -2814,7 +2417,7 @@ L<ini|Tripletail::Ini> で指定されたアドレスにエラーメールを送
 C<$coding> が省略された場合は C<'auto'> となる。C<$prefer_encode> を真
 にすると L<Encode> が利用可能な場合は L<Encode> で変換する。
 
-=head4 C<< writeFile >>
+=item C<< writeFile >>
 
   $TL->writeFile($fpath, $fdata, $fmode);
 
@@ -2826,7 +2429,7 @@ C<$fmode> が1ならば、追加モード。
 
 省略された場合は上書きモードとなる。
 
-=head4 C<< writeTextFile >>
+=item C<< writeTextFile >>
 
   $TL->writeTextFile($fpath, $fdata, $fmode, $coding, $prefer_encode);
 
@@ -2841,7 +2444,7 @@ C<$fmode> が1ならば、追加モード。
 C<$coding> が省略された場合、utf8として扱う。C<$prefer_encode> を真にする
 と L<Encode> が利用可能な場合は L<Encode> で変換する。
 
-=head4 C<< watch >>
+=item C<< watch >>
 
   $TL->watch(sdata => \$sdata, $reclevel);
   $TL->watch(adata => \@adata, $reclevel);
@@ -2857,22 +2460,18 @@ C<$coding> が省略された場合、utf8として扱う。C<$prefer_encode> 
 
 また、再帰的にウォッチする場合、変数名は親の変数名を利用して自動的に設定される。
 
-=head4 C<< dump >>
+=item C<< dump >>
 
-  $TL->dump(\$data);
-  $TL->dump(\$data, $level);
   $TL->dump(DATA => \$data);
   $TL->dump(DATA => \$data, $level);
 
 第2引数に変数へのリファレンスを渡すと，その内容を Data::Dumper でダンプし、
 第1引数のグループ名で $TL->log を呼び出す。
 
-第1引数のグループ名は省略可能。
-
 第3引数で、リファレンスをどのくらいの深さまで追うかを指定することが出来る。
 指定しなければ全て表示される。
 
-=head4 C<< printCacheUnlessModified >>
+=item C<< printCacheUnlessModified >>
 
   $bool = $TL->printCacheUnlessModified($key, $flag, $param, $charset)
 
@@ -2906,7 +2505,7 @@ UTF-8，Shift_JIS，EUC-JP，ISO-2022-JP
 
 この関数からundefを返された場合、以後出力を行う操作を行ってはならない。
 
-=head4 C<< setCache >>
+=item C<< setCache >>
 
   $TL->setCache($key, $param, $charset, $priority)
 
@@ -2933,7 +2532,7 @@ UTF-8，Shift_JIS，EUC-JP，ISO-2022-JP
 Tripletail::Filter::MemCachedは必ず最後に実行する必要性があるため、
 1500以上の優先度で設定するフィルタが他にある場合は手動で設定する必要がある。
 
-=head4 C<< deleteCache >>
+=item C<< deleteCache >>
 
   $TL->deleteCache($key)
 
@@ -2947,13 +2546,15 @@ Tripletail::Filter::MemCachedは必ず最後に実行する必要性があるた
 該当するキャッシュを削除するように使用する。
 それにより、次回アクセス時に最新の情報が出力される。
 
-=head4 C<< getDebug >>
+=item C<< getDebug >>
 
-=head4 C<< newError >>
+=item C<< newError >>
 
 内部用メソッド。
 
 
+=back
+
 =head2 Ini パラメータ
 
 グループ名は常に B<TL> でなければならない。
@@ -3135,7 +2736,6 @@ startCgi メソッド中で出力をバッファリングする。デフォル
 
 各種タイムアウト時間，セッションのexpiresなど、
 時間間隔は以下の指定が可能とする。
-数値化には L</parsePeriod> を使用する. 
 
 単位は大文字小文字を区別しない。
 
@@ -3163,11 +2763,7 @@ startCgi メソッド中で出力をバッファリングする。デフォル
 
 =item 数値＋ 'mon' or 'month' or 'months'
 
-月での指定を表す。１月＝30.436875日として計算する。 [×30.436875*24*3600]
-
-=item 数値＋ 'year' or 'years'
-
-年での指定を表す。１年＝365.2425日として計算する。 [×365.2425*24*3600]
+月での指定を表す。１月＝30日として計算する。 [×30*24*3600]
 
 =back
 
@@ -3176,8 +2772,6 @@ startCgi メソッド中で出力をバッファリングする。デフォル
 メモリサイズ、文字列サイズ等、大きさを指定する場合には、
 以下の指定が可能とする。英字の大文字小文字は同一視する。
 
-数値化には L</parseQuantity> を使用する. 
-
 =head4 10進数系
 
 =over 4
@@ -3242,112 +2836,6 @@ startCgi メソッド中で出力をバッファリングする。デフォル
 
 =back
 
-=head1 SAMPLE
-
- perldoc -u Tripletail |  podselect -sections SAMPLE | sed -e '1,4d' -e 's/^ //'
-
-
- # master configurations.
- #
- [TL]
- logdir=/home/project/logs/error
- errormail=errors@your.address
- errorlog=2
- trap=diewithprint
- stackallow=0.0.0.0/0
- 
- [TL:SmallDebug]
- stacktrace=onlystack
- outputbuffering=1
- 
- [TL:Debug]
- stacktrace=full
- outputbuffering=1
- 
- [TL:FullDebug]
- stacktrace=full
- outputbuffering=1
- stackallow=0.0.0.0/0
- 
- # database configrations.
- #
- [DB]
- type=mysql
- namequery=1
- tracelevel=0
- AllTransaction=DBALL
- defaultset=AllTransaction
- [DBALL]
- dbname=
- user=
- password=
- #host=
- 
- [DB:SmallDebug]
- 
- [DB:Debug]
- 
- [DB:FullDebug]
- tracelevel=2
- 
- # debug configrations.
- #
- [Debug]
- enable_debug=0
- 
- [Debug:SmallDebug]
- enable_debug=1
- 
- [Debug:Debug]
- enable_debug=1
- request_logging=1
- content_logging=1
- warn_logging=1
- db_profile=1
- popup_type=single
- template_popup=0
- request_popup=1
- db_popup=0
- log_popup=1
- warn_popup=1
- 
- [Debug:FullDebug]
- enable_debug=1
- request_logging=1
- content_logging=0
- warn_logging=1
- db_profile=1
- popup_type=single
- template_popup=1
- request_popup=1
- db_popup=1
- log_popup=1
- warn_popup=1
- location_debug=1
- 
- # misc.
- #
- [SecureCookie]
- path=/
- secure=1
- 
- [Session]
- mode=https
- securecookie=SecureCookie
- timeout=30min
- updateinterval=10min
- dbgroup=DB
- dbset=AllTransaction
- 
- # user data.
- # you can read this data:
- # $val = $TL->INI->get(UserData=>'roses');
- #
- [UserData]
- roses=red
- violets=blue
- sugar=sweet
-
 =head1 SEE ALSO
 
 =over 4
