@@ -6,19 +6,10 @@ use Tripletail;
 use strict;
 use warnings;
 require Tripletail::Template::Node;
-require File::Spec::Functions;
-
-our %_REL2ABS_CACHE;
+require File::Spec;
 
 1;
 
-sub __rel2abs
-{
-	my $path = shift;
-	my $base = shift;
-	$_REL2ABS_CACHE{"$path\0$base"} ||= File::Spec::Functions::rel2abs($path, $base);
-}
-
 sub _new {
 	my $class = shift;
 	my $this = bless {} => $class;
@@ -26,11 +17,6 @@ sub _new {
 	$this->{root} = Tripletail::Template::Node->_new;
 
 	$this->{basepath} = $TL->INI->get('Template' => 'basepath', '.');
-	if( !File::Spec::Functions::file_name_is_absolute($this->{basepath}) )
-	{
-		my $cwd = $TL::CWD || $TL->_cwd;
-		$this->{basepath} = __rel2abs($this->{basepath}, $cwd);
-	}
 	$this->{rootpath} = $TL->INI->get('Template' => 'rootpath', '/');
 
 	$TL->getDebug->_templateLog(
@@ -45,24 +31,18 @@ sub _new {
 	$this;
 }
 
-sub _checkPathIsAcceptable {
+sub _checkPath {
 	my $this = shift;
 	my $path = shift;
-	
-	if( $this->{rootpath} eq '/' )
-	{
-		return; # void.
-	}
 
 	# rootpathチェック
-	my @rootpath = File::Spec::Functions::splitdir(
-		File::Spec::Functions::canonpath($this->{rootpath})
+	my @rootpath = File::Spec->splitdir(
+		File::Spec->canonpath($this->{rootpath})
 	);
 	length $rootpath[-1] or pop @rootpath;
-	@rootpath && length $rootpath[-1] or pop @rootpath;
 
-	$path = File::Spec::Functions::canonpath($path);
-	my @path = File::Spec::Functions::splitdir($path);
+	$path = File::Spec->canonpath($path);
+	my @path = File::Spec->splitdir($path);
 
 	my @abspath;
 	foreach my $dir (@path) {
@@ -75,12 +55,12 @@ sub _checkPathIsAcceptable {
 
 	for(my $i = 0; $i < @rootpath; $i++) {
 		if($rootpath[$i] ne $abspath[$i]) {
-			die __PACKAGE__."#_checkPathIsAcceptable, loading file [$path] was forbidden ".
+			die __PACKAGE__."#_checkPath, loading file [$path] was forbidden ".
 				"due to rootpath being [$this->{rootpath}]\n";
 		}
 	}
 
-	return; # void.
+	$path;
 }
 
 sub _expandInclude {
@@ -105,8 +85,8 @@ sub _expandInclude {
 	# <!include>を処理
 	$str =~ s{<!include:(.+?)>}{
 		my $filepath = $1;
-		$filepath = __rel2abs($filepath, $basedir);
-		$this->_checkPathIsAcceptable($filepath);
+		$filepath = File::Spec->rel2abs($filepath, $basedir);
+		$filepath = $this->_checkPath($filepath);
 		$this->{loadfile}{$filepath} = 1;
 		my $includestr = $TL->readTextFile($filepath);
 		$includestr = $this->_expandInclude($inccount, $includestr, $filepath);
@@ -151,9 +131,10 @@ sub loadTemplate {
 		die __PACKAGE__."#loadTemplate, ARG[1] was Ref.\n";
 	}
 
-	$filepath = __rel2abs($filepath, $this->{basepath});
+	$filepath = File::Spec->rel2abs($filepath, $this->{basepath});
 
-	$this->_checkPathIsAcceptable($filepath);
+	$filepath = $this->_checkPath($filepath);
+	$this->_checkPath($filepath);
 
 	my $str = $TL->readTextFile($filepath, $icode);
 	my $inccount = 0;
